<?php
/**
* Lab 4 Assignment
* COMP453 - Fall 2014
*
* @author Elliott Post & Channah Naiman
* @link http://ellytronic.media
* @since Oct 10, 2014
*/

//set up some defaults to avoid requiring isset
$errorMessage = null;
$investment = null;
$rate = 5; //default shouldn't be null for this
$years = null;
$futureValue = null;

//run some calcs if the form is submitted, this shouldn't ever actually happen unless JS is disabled
if( isset( $_POST['calculator-submit'] ) && isset( $_POST['investment'] ) && isset( $_POST['rate'] ) && isset( $_POST['years'] ) ):
    $investment = $_POST['investment'];
    $rate = $_POST['rate'];
    $years = $_POST['years'];

    //set up our condition so we can easily escape back to the form
    while( 1 ):
        //ensure investment positive and an int or float
        if( !preg_match( "/^-?[0-9]+(?:\.[0-9]{1,2})?$/", $investment ) || (float) $investment < 0) {
            $errorMessage = "Please enter a positive real number for the amount.";
            break;
        }

        //ensure rate is valid
        if( filter_var( $rate, FILTER_VALIDATE_FLOAT) || filter_var( $rate, FILTER_VALIDATE_INT ) || (float) $rate < 0 || (float) $rate > 100 ) {
            $errorMessage = "Please enter a valid number between 0 and 100 for the interest rate.";
            break;
        }

        //ensure number of years is int and positive
        if( filter_var( $years, FILTER_VALIDATE_INT ) || (int) $years < 0 ) {
            $errorMessage = "Please enter a valid integer greater than 0 for the years.";
            break;
        }


        $futureValue = $investment;
        //modified slightly to be easier to read
        for ($i = 1; $i <= $years; $i++) {
            $futureValue += $futureValue * $rate * .01;
        }
        break; //don't forget to break or you'll be stuck forever!
    endwhile;
endif;

/**
* Formats a number uses the best possible method
* assumes EN_US currrency formatting.
*
* @param float $val: the number to be formatted.
* @since Oct 10, 2014
*/
function formatVal( $val ) {
    //use a better function if it exists. Not installed in all PHP distros (eg: windows - blergh windows servers are the scourge of the universe!!)
    if( function_exists( 'money_format' ) ) {
        setlocale( LC_MONETARY, 'en_US' );
        return money_format( '%.2', $val );
    }
    return "$" . number_format( $val );
}


?><!DOCTYPE html>
<head>
    <title>Future Value Calculator</title>
    <!--[if lt IE 9]>
        <script src="//html5shiv.googlecode.com/svn/trunk/html5.js"></script>
    <![endif]-->
    <style>
        body {
            font-family: Arial, Helvetica, sans-serif;
        }
        #content {
            width: 450px;
            margin: 0 auto;
            padding: 20px 20px;
            background: white;
            border: 2px solid navy;
        }
        h1 {
            color: navy;
        }
        label {
            width: 10em;
            padding-right: 1em;
            float: left;
        }
        #data input {
            float: left;
            width: 15em;
            margin-bottom: .5em;
        }
        input#rate {
            width:8em;
            margin-right:0.5em;
        }
        input#rate-num {
            float:left;
            width:auto;
        }
        #buttons input {
            float: left;
            margin-bottom: .5em;
        }
        br {
            clear: left;
        }
        .error {
            color: red;
            font-weight: bold;
        }
        .success {
            color:green;
            font-weight:700;
        }
    </style>
</head>

<body>
    <div id="content">
    <h1>Future Value Calculator</h1>

    <?php if( $futureValue ):
        echo "<p class='success'>Your future value is: " . formatVal( $futureValue ) . "</p>";
    endif;
    ?>

    <p class='success' id='js-success' style='display: none'></p>

    <span class='error'><?=$errorMessage?></span>
    <form method="POST" action="#" id="frm-calculator">
        <div id="data">
            <label for="investment">Investment Amount:</label>
            <input type="number" name="investment" id="investment" min="0" step="0.01" placeholder="1000.00" value="<?=$investment?>" required>
            <div style="clear:left;"></div>
            <label for="rate">Yearly Interest Rate:</label>
            <input type="range" name="rate" id="rate" min="0" max="100" placeholder="15" step="0.01" value="5" value="<?=$rate?>" required>
            <input type="number" name="rate-num" id="rate-num" min="0" max="100" step="0.01" value="<?=$rate?>" placeholder="Select" required>%
            <div style="clear:left;"></div>
            <label for="years">Number of Years:</label>
            <input type="number" name="years" id="years" min="0" max="100" step="1" value="<?=$years?>" placeholder="15" required>
            <div style="clear:left;"></div>

        </div>

        <div id="buttons">
            <input type="submit" id="submit" name="calculator-submit" value="Calculate <?php if($futureValue) echo 'Another Value';?>">
            <div style="clear:left;"></div>
        </div>

    </form>
    </div>
    <script src="//ajax.googleapis.com/ajax/libs/jquery/1.11.1/jquery.min.js"></script>
    <script>
    <!--
    jQuery( document ).ready( function($) {
        //don't allow less than 0
        $('input').on( "change", function(){
            if( $(this).val() < 0 )
                $(this).val( 0 );
        });

        //keep the slider and numbers in sync
        $("#rate").on( "change", function(){
            $( "#rate-num" ).val( $(this).val() );
        });
        $("#rate-num").on( "change", function(){
            $( "#rate" ).val( $(this).val() );
        });

        //make year be a whole number
        $("#years").on( "change", function(){
            $(this).val( Math.floor( $(this).val() ) );
        });

        //capture the submit
        $( document ).on( "submit", "#frm-calculator", function(e){
            //don't actually submit
            e.preventDefault();

            var futureVal = parseFloat( $( "#investment" ).val() );
            var rate = parseFloat( $( "#rate-num" ).val() );
            var years = parseInt( $( "#years" ).val() );

            for( var i = 1; i <= years; i++ )
                futureVal += futureVal * rate * .01;

            /**
             * format the number as currency
             * @link http://stackoverflow.com/questions/149055/how-can-i-format-numbers-as-money-in-javascript?page=1&tab=votes#tab-top
             */
            $( "#js-success" ).text( "Your future value is: $" + futureVal.toFixed(2).replace(/(\d)(?=(\d{3})+\.)/g, '$1,') ).show(0);

        });
    }); //-->
    </script>
</body>
</html>
